// Last edited on 2011-04-23 21:34:03 by stolfi
// Generic figure of whole Fukushima Daiichi Unit 1 reactor.

#include "coord_axes.inc"
#include "lamp_array.inc"
#include "camlight.inc"
#include "cutters.inc"
#include "generic_parts.inc"
#include "textures.inc"

background{ color rgb < 0.070, 0.070, 0.040 > }

#macro generic_fig(OB,view)
  // Generic figure of object {OB}.
  // Positions the camera and lights.
  // {view} = 
  //   1 = from south looking north.
  //   2 = from east looking west.
  //   3 = from SE above.
  //   4 = from above looking down.
  
  // Choose the cutter and camera placement:
  #if (view = 1)
    #declare cam_dir = -y; // From south looking north.
    #declare cam_dst = 5000;
    #declare cam_upp = +z;
  #end
  
  #if (view = 2)
    #declare cam_dir = +x; // From east looking west.
    #declare cam_dst = 5000;
    #declare cam_upp = +z;
  #end
  
  #if (view = 3)
    #declare cam_dir = <5,-4,3>;
    #declare cam_dst = 0; // Decide later.
    #declare cam_upp = +z;
  #end
  
  #if (view = 4)
    #declare cam_dir = +z;
    #declare cam_dst = 5000; // From above looking down.
    #declare cam_upp = +y;
  #end
  
  #local lo_corner = min_extent(OB);
  #local hi_corner = max_extent(OB);
  
  debug_point("lo_corner", lo_corner)
  debug_point("hi_corner", hi_corner)

  #if ((view = 1) | (view = 2) | (view = 4))
    #declare cam_ctr = un1_reactor_axis + 20.800*z;
    #declare cam_rad = 46.500;
    #declare cam_lux = 1.0;
    #declare cam_lnr = 2;
    #declare cam_lar = 5.0;
    #declare cam_lct = 1;
    #local scene = object{ OB }
  #else
    #declare cam_ctr = (lo_corner + hi_corner)/2;
    #declare cam_rad = 1.4*vlength(hi_corner - lo_corner)/2;
    #declare cam_lux = 1.2;
    #declare cam_lnr = 2;
    #declare cam_lar = 3.0;
    #declare cam_lct = 0;
    #local scene =
      union{ 
        // object{ sky() }
        object{ OB } 
        object{ coord_axes(cam_rad) }
      }
  #end
  #if (cam_dst <= 0)
    #declare cam_dst = 8*cam_rad;
  #end

  object{ scene }
  
  camlight(cam_ctr,cam_rad,cam_dir,cam_dst,cam_upp, cam_lux,cam_lnr,cam_lar,cam_lct)
#end
