// Last edited on 2011-04-23 19:27:41 by stolfi
// Reactor dimensions (temporary - for unit #1)

// Based on Fukushima Daiichi reactor #1 blueprints
// http://www.houseoffoust.com/fukushima/reactorblueprint.jpg
// Blueprint scale on my PC's screen: 1mm = 0.19314 m
// Blueprint scale on my HP laptop's screen 1mm = 0.20907 m

// rOP = Z coord relative to blueprint's reference Z "OP"
// OP = Onahama Port Standard Construction Level = (Tokyo Bay Mean Standard Level) + 0.727 m
// RPV = reactor pressure vessel.
// SFP = spent-fuel pool.
// DSP = dryer separator storage pool.
// CLP = cask-loading pool (?).
// ELW = elevator well.
// DW = drywell, the lighbulb-shaped part of primary containment.
// SC = surge suppression chamber, aka torus.

// [EB] = eyeball estimate from blueprint; may be wrong by 100 mm or more.
// [TBC] = vague recollection, to be confirmed.
// Untagged values are explicitly given in blueprint.

// Here is a perspective cutaway view of Unit 1:
// http://www.beyondnuclear.org/home/2011/3/12/fukushima-dai-ichi-unit-1-reactor-schematic.html 

// OVERALL BUILDING

#declare un1_building_base_Z = -4.000;         // Z of bottom of basement concrete floor rOP.

#declare un1_building_base_size = < 41.560, 41.560, 26.100 >;  // Dims of base of building.
#declare un1_building_body_size = < 31.420, 41.560, 59.300 >;  // Dims of building up to roof wall.

#declare un1_ground_Z = +10.000; // Z of ground outside unit rOP.

#declare un1_service_floor_Z = +38.900; 

#declare un1_reactor_axis = 
  < 20.780, 20.780, 00.000 >; // {X,Y} of core axis rel to reactor's origin.
  
#declare un1_exterior_paint_thk = 0.002; // Nominal thickness of exterior paint.  
  
#declare eps = 0.0001;              // Fudge factor to avoid coincident surfaces.
#declare epsv = < eps, eps, eps >;  // Fudge vector for box corners.

// SECONDARY CONTAINMENT

#declare un1_drywell_sphere_ctr_Z = 12.200;     // Z of drywell sphere center rOP.
#declare un1_drywell_sphere_rad = 8.980;        // Radius of drywell sphere.
#declare un1_drywell_stem_rad = 4.730;          // Radius of main drywell cylinder.
#declare un1_drywell_thk = 0.025;               // Drywell wall thickness [TBC].

#declare un1_drywell_floor_Z = 6.180;           // Z of concrete floor inside drywell rOP.

#declare un1_shroud_Z = 31.680;                 // Z of seal between drywell and shroud rOP [EB].
#declare un1_shroud_size_Z = 3.860;             // Total height of shroud [EB].
#declare un1_shroud_cyl_size_Z = 1.350;         // Height of straight part of shroud [EB].
#declare un1_shroud_thk = 0.025;                // Shroud wall thickness [TBC].

#declare un1_drywell_flange_thk = 0.200;        // Vertical thickness of drywell/shroud flange [TBC].
#declare un1_drywell_flange_rad = 0.100;        // Extra radius of drywell/shroud flange [TBC].

// Cylindrical well where the drywell shroud lives:
#declare un1_shroud_cavity_Z = 30.700;          // Z of bottom of shroud well rOP.
#declare un1_shroud_cavity_rad = 5.800;         // Radius of shroud well [EB].

#declare un1_shield_plug_thk = 0.600;           // Thickness of shield plugs [EB].
#declare un1_shield_plug_step = 0.200;          // Width of steps that support the shield plugs [EB].

#declare un1_torus_ctr_Z = +3.570;              // Z of torus center rOP.
#declare un1_torus_major_rad = 14.710;          // Major radius of torus [EB].
#declare un1_torus_minor_rad =  4.150;          // Minor radius of torus.
#declare un1_torus_thk = 0.025;                 // Torus wall thickness [TBC].

// The toroidal distribution pipe inside the suppression chamber:
#declare un1_inner_torus_major_rad = 14.710;    // Major radius of inner torus [EB].
#declare un1_inner_torus_minor_rad =  0.650;    // Minor radius of inner torus.
#declare un1_inner_torus_thk = 0.012;           // Torus wall thickness [TBC].

// The annular cavity in the building where the torus sits:
#declare un1_torus_storey_west_wall_thk  = 1.300;  // Typical thickness of -X outer wall [EB].
#declare un1_torus_storey_east_wall_thk  = 1.300;  // Typical thickness of +X outer wall [EB].

#declare un1_torus_storey_south_wall_thk = 1.300;  // Typical thickness of -Y outer wall [EB].
#declare un1_torus_storey_north_wall_thk = 1.300;  // Typical thickness of -Y outer wall [EB].

#declare un1_torus_storey_floor_Z   = -1.230;     // Z of bottom of cavity rOP.
#declare un1_torus_storey_ceiling_Z = +9.400;     // Z of top of cavity rOP [EB].

// Surge pipes between torus and drywell.
// The following are relative to the reactor axis, OP height,
// assuming pipe axis on XZ plane:
#declare un1_surge_pipe_bot_ref_X    = +14.710; // X of center of discharge hole [EB].
#declare un1_surge_pipe_bot_ref_Z    =  +4.820; // Z of center of discharge hole [EB].
#declare un1_surge_pipe_top_ref_X    =  +6.750; // X of center of mouth inside drywell [EB].
#declare un1_surge_pipe_top_ref_Z    =  +7.750; // Z of center of mouth inside drywell [EB].
#declare un1_surge_pipe_sleeve_top_X =  +6.750; // X of center of sleeve face [EB].
#declare un1_surge_pipe_sleeve_top_Z =  +7.750; // Z of center of sleeve face [EB].
// The following assume that the pipe axis is the Z axis, 
// with the discharge hole centered on the origin:
#declare un1_surge_pipe_cap_Z        = -1.000; // Z of bottom cap center [EB].
#declare un1_surge_pipe_cap_H        =  0.450; // Height of bottom cap [EB].
#declare un1_surge_pipe_cap_rad      =  0.900; // Radius of bottom cap and cylinder [EB].
#declare un1_surge_pipe_cone_lo_Z    = +6.700; // Low Z of radius transition [EB].
#declare un1_surge_pipe_cone_hi_Z    = +7.300; // High Z of radius transition [EB].
#declare un1_surge_pipe_top_Z        = +8.360; // Nominal Z of top end of pipe [EB].
#declare un1_surge_pipe_top_rad      =  1.050; // Radius of top cylinder [EB].
#declare un1_surge_pipe_bellows_lo_Z = +4.000; // Low Z of bellows joint [EB].
#declare un1_surge_pipe_bellows_hi_Z = +5.200; // High Z of bellows joint [EB].
#declare un1_surge_pipe_bellows_rad  =  1.050; // Outer radius of bellows joint [EB].    
#declare un1_surge_pipe_niche_back_Z =  5.850; // Z of back wall of bellows niche [EB].  
#declare un1_surge_pipe_niche_rad    =  1.250; // Radius of bellows niche [EB]. 
#declare un1_surge_pipe_hole_rad     =  0.600; // Radius of discharge hole [EB]. 
#declare un1_surge_pipe_thk          =  0.025; // Thickness of surge pipe [TBC].

#declare un1_surge_pipe_sleeve_rad   =  1.200; // Outer radius of sleeve [EB].

// CONCRETE ENCLOSURE OF DRYWELL
 
#declare un1_drywell_enclosure_cyl0_bot_Z = -1.230;     // Nominal bottom Z of cylinder 0 rOP.
#declare un1_drywell_enclosure_cyl0_rad = 10.140;       // Radius of cylinder 0.
#declare un1_drywell_enclosure_cyl0_top_Z = +5.500;     // Top Z of cylinder 0 rOP.

#declare un1_drywell_enclosure_cone1_bot_Z = +5.500;    // Bottom Z of cone 1 [EB].
#declare un1_drywell_enclosure_cone1_bot_rad = 10.140;  // Bottom Radius of cone 1.
#declare un1_drywell_enclosure_cone1_top_rad = 10.600;  // Top radius of cone 1 [EB].
#declare un1_drywell_enclosure_cone1_top_Z = +8.400;    // Top Z of cone 1 rOP [EB].

#declare un1_drywell_enclosure_cyl1_bot_Z = +8.400;     // Nominal bottom Z of cylinder 1 rOP.
#declare un1_drywell_enclosure_cyl1_rad = 10.600;       // Radius of cylinder 1.
#declare un1_drywell_enclosure_cyl1_top_Z = +18.700;    // Top Z of cylinder 1 rOP.

#declare un1_drywell_enclosure_cone2_bot_Z = +18.700;   // Bottom Z of cone 2 [EB].
#declare un1_drywell_enclosure_cone2_bot_rad = 8.700;   // Bottom Radius of cone 2 [EB].
#declare un1_drywell_enclosure_cone2_top_rad = 6.760;   // Top radius of cone 2.
#declare un1_drywell_enclosure_cone2_top_Z = +22.100;   // Top Z of cone 2 rOP [EB].

#declare un1_drywell_enclosure_cyl2_bot_Z = +22.100;    // Nominal bottom Z of cylinder 2 rOP [EB].
#declare un1_drywell_enclosure_cyl2_rad = 6.760;        // Radius of cylinder 2.
#declare un1_drywell_enclosure_cyl2_top_Z = +28.000;    // Top Z of cylinder 2 rOP [EB].

// The following can be considered part of the refueling pool:

#declare un1_drywell_enclosure_cone3_bot_Z = +28.000;   // Bottom Z of cone 3 [EB].
#declare un1_drywell_enclosure_cone3_bot_rad = 6.760;   // Bottom Radius of cone 3.
#declare un1_drywell_enclosure_cone3_top_rad = 7.200;   // Top radius of cone 3 [EB].
#declare un1_drywell_enclosure_cone3_top_Z = +29.000;   // Top Z of cone 3 rOP [EB].

#declare un1_drywell_enclosure_cyl3_bot_Z = +29.000;    // Nominal bottom Z of cylinder 3 rOP [EB].
#declare un1_drywell_enclosure_cyl3_rad = 7.200;        // Radius of cylinder 3 [EB].
#declare un1_drywell_enclosure_cyl3_top_Z = +38.900;    // Top Z of cylinder 3 rOP.

// REACTOR PRESSURE VESSEL

#declare un1_rpv_body_height = 16.400; // Length of cylindrical part of RPV [EB].
#declare un1_rpv_body_rad =  2.310;    // Outer radius of RPV [EB].
#declare un1_rpv_thk = 0.150;          // Thickness of RPV wall [TBC].
#declare un1_rpv_flange_thk = 0.800;   // Thickness of RPV flanges [EB].
#declare un1_rpv_flange_rad = 0.500;   // Extra radius of RPV flanges [EB].
#declare un1_rpv_Z = 15.200;           // Z of center of bottom RPV head rOP [TBC]. 

// REACTOR FUEL

#declare un1_reactor_fuel_height =  4.000; // Vertical length of fuel pack [TBC].
#declare un1_reactor_fuel_rad    =  1.880; // Radius of fuel pack [TBC].
#declare un1_reactor_fuel_Z      = +5.000; // Z of fuel bottom rel ctr bottom head [TBC].

// REACTOR VESSEL SUPPORT

#declare un1_rpv_supp_lo_in_rad = 2.550;  // Bottom inner radius of RPV support [EB].
#declare un1_rpv_supp_lo_ot_rad = 3.750;  // Bottom outer radius of RPV support [EB].

#declare un1_rpv_supp_md1_in_Z = +12.200; // Bottom Z of inner radius transition.
#declare un1_rpv_supp_md2_in_Z = +12.800; // Top Z of inner radius transition [EB].
#declare un1_rpv_supp_md_ot_Z =  +14.580; // Z of outer radius transition [EB].

#declare un1_rpv_supp_md_in_rad =  1.950; // Inner radius of RPV support shoulder [EB].

#declare un1_rpv_supp_hi_in_rad =  2.310; // Top inner radius of RPV support [EB].
#declare un1_rpv_supp_hi_ot_rad =  3.500; // Top outer radius of RPV support [EB].
#declare un1_rpv_supp_hi_Z =     +27.800; // Top of RPV support [EB].

// SPENT-FUEL POOL

#declare un1_sfp_lo_Y = +6.260;          // Low Y of SFP cavity, rel south wall [EB].
#declare un1_sfp_lo_Z = +27.100;         // Z of bottom of SFP cavity rOP.
#declare un1_sfp_size_X = 14.000;        // X size of SFP cavity [TBC].
#declare un1_sfp_size_Y = 7.260;         // Y size of SFP cavity [EB].
#declare un1_sfp_wall_thk = 1.500;       // Thickness of SFP walls [TBC].
#declare un1_sfp_size_Z = un1_service_floor_Z - un1_sfp_lo_Z;    // Height of SFP cavity.

#declare un1_sfp_channel_lo_Z = +31.300;   // Z of bottom of channel to SFP cavity rOP [EB].
#declare un1_sfp_channel_wid = 2.000;      // Width of channel to SFP cavity [TBC].
#declare un1_sfp_channel_wall_thk = 1.500; // Thickness of SFP channel walls [TBC].
#declare un1_sfp_channel_size_Z = 
  un1_service_floor_Z - un1_sfp_channel_lo_Z;  // Height of channel to SFP cavity.

#declare un1_sfp_gate_thk = 0.500;              // Thickness of gate to SFP cavity [EB].

// DRYER SEPARATOR STORAGE POOL (= EQUIPMENT-HANDLING POOL?)

#declare un1_dsp_lo_Z = +31.300;         // Z of bottom of DSP cavity rOP.
#declare un1_dsp_lo_Y = +28.040;         // Low Y of DSP cavity, rel south wall [EB].
#declare un1_dsp_size_X = 10.000;        // X size of DSP cavity [TBC].
#declare un1_dsp_size_Y = 12.620;        // Y size of DSP cavity [EB].
#declare un1_dsp_wall_thk = 0.900;       // Thickness of DSP cavity wall [TBC].
#declare un1_dsp_size_Z = un1_service_floor_Z - un1_dsp_lo_Z;  // Height of DSP cavity.

#declare un1_dsp_channel_lo_Z = +31.300;   // Z of bottom of channel to DSP cavity rOP [TBC].
#declare un1_dsp_channel_wid = 2.000;      // Width of channel to DSP cavity [TBC].
#declare un1_dsp_channel_wall_thk = 0.900; // Thickness of DSP channel wall [TBC].
#declare un1_dsp_channel_size_Z = 
  un1_service_floor_Z - un1_dsp_channel_lo_Z;  // Height of gate to DSP cavity.

#declare un1_dsp_gate_thk = 0.500;        // Thickness of gate to DSP cavity [EB].

// CASK LOADING POOL (?)

#declare un1_clp_lo_Z = +31.300;          // Z of bottom of CLP cavity rOP [TBC].
#declare un1_clp_lo_X = +8.100;           // Low X of CLP cavity, rel west wall [TBC].
#declare un1_clp_size_X = 3.300;          // X size of CLP cavity [TBC].
#declare un1_clp_size_Y = 5.000;          // Y size of CLP cavity [TBC].
#declare un1_clp_wall_thk = 0.600;        // Thickness of CLP cavity wall [TBC].
#declare un1_clp_size_Z = 
  un1_service_floor_Z - un1_clp_lo_Z; // Height of CLP cavity.

#declare un1_clp_channel_lo_Z = +34.300;      // Z of bottom of channel to CLP cavity rOP [TBC].
#declare un1_clp_channel_wid = 2.000;         // Width of channel to CLP cavity [TBC].
#declare un1_clp_channel_wall_thk = 0.600;    // Thickness of CLP cavity wall [TBC].
#declare un1_clp_channel_size_Z = 
  un1_service_floor_Z - un1_clp_channel_lo_Z; // Height of channel to CLP cavity.

#declare un1_clp_gate_thk = 0.300;        // Thickness of gate to CLP cavity [TBC].

// ELEVATOR WELL 

#declare un1_elw_lo_Z = +8.100;           // Z of bottom of ELW cavity rOP.
#declare un1_elw_lo_X = +1.300;           // Low Y of ELW cavity, rel south wall [EB].
#declare un1_elw_lo_Y = +34.800;          // Low Y of ELW cavity, rel south wall [EB].
#declare un1_elw_size_X = 3.700;          // X size of ELW cavity [EB].
#declare un1_elw_size_Y = 3.700;          // Y size of ELW cavity [EB].
#declare un1_elw_wall_thk = 0.000;        // Thickness of ELW wall (none).
#declare un1_elw_size_Z = 
  un1_service_floor_Z - un1_elw_lo_Z; // Height of ELW cavity.

#declare un1_elw_channel_lo_Z = +34.300;   // Z of bottom of channel to ELW cavity, rOP.
#declare un1_elw_channel_wid = 2.000;      // Y size of channel to ELW cavity [TBC].
#declare un1_elw_channel_wall_thk = 0.600; // Thickness of ELW channel wall [TBC].
#declare un1_elw_channel_size_Z = 
  un1_service_floor_Z - un1_elw_channel_lo_Z;  // Height of gate to ELW cavity.

#declare un1_elw_gate_thk = 0.300;        // Thickness of gate to DSP cavity [EB].

// REACTOR HYDRAULICS STOREY

#declare un1_hydraulics_storey_west_wall_thk = 1.200; // Typical thickness of -X outer wall [EB].
#declare un1_hydraulics_storey_east_wall_thk = 1.200; // Typical thickness of +X outer wall [TBC].

#declare un1_hydraulics_storey_south_wall_thk = 1.200; // Typical thickness of -Y outer wall [EB].
#declare un1_hydraulics_storey_north_wall_thk = 1.200; // Typical thickness of +Y outer wall [EB].

#declare un1_hydraulics_storey_lo_Z = +10.200;     // Z of floor rOP.
#declare un1_hydraulics_storey_md1_X = +10.780;    // First X where ceiling Z changes.
#declare un1_hydraulics_storey_md2_X = +30.780;    // Second X where ceiling Z changes.
#declare un1_hydraulics_storey_ws_hi_Z = +17.100;  // Z of ceiling on West part rOP [EB].
#declare un1_hydraulics_storey_md_hi_Z = +17.800;  // Z of ceiling on WE central part rOP [EB].
#declare un1_hydraulics_storey_es_hi_Z = +17.600;  // Z of ceiling on East part rOP [EB].

#declare un1_hydraulics_storey_drywell_enclosure_rad = 10.500; // Radius of DW concrete enclosure.

// STEAMPIPES STOREY

#declare un1_steampipes_storey_west_wall_thk = 0.000; // Typical thickness of -X outer wall [EB].
#declare un1_steampipes_storey_east_wall_thk = 1.200; // Typical thickness of +X outer wall [EB].

#declare un1_steampipes_storey_south_wall_thk = 0.500; // Typical thickness of -Y outer wall [TBC].
#declare un1_steampipes_storey_north_wall_thk = 0.500; // Typical thickness of +Y outer wall [TBC].

#declare un1_steampipes_storey_lo_Z = +10.200;      // Z of floor rOP.
#declare un1_steampipes_storey_hi_Z = +16.600;      // Z of ceiling in east part rOP [TBC].

// HEATING AND VENTILATION STOREY

#declare un1_hvac_storey_west_wall_thk = 0.000; // Typical thickness of -X outer wall [EB].
#declare un1_hvac_storey_east_wall_thk = 0.500; // Typical thickness of +X outer wall [EB].

#declare un1_hvac_storey_south_wall_thk = 0.500; // Typical thickness of -Y outer wall [EB].
#declare un1_hvac_storey_north_wall_thk = 0.500; // Typical thickness of +Y outer wall [EB].

#declare un1_hvac_storey_lo_Z = +17.100;      // Z of floor rOP.
#declare un1_hvac_storey_hi_Z = +21.600;      // Z of ceiling in east part rOP [TBC].

// COOLING SYSTEMS STOREY

#declare un1_cooling_storey_west_wall_thk = 1.000; // Typical thickness of -X outer wall [EB].
#declare un1_cooling_storey_east_wall_thk = 0.800; // Typical thickness of +X outer wall [EB].

#declare un1_cooling_storey_south_wall_thk = 1.200; // Typical thickness of -Y outer wall [EB].
#declare un1_cooling_storey_north_wall_thk = 1.200; // Typical thickness of +Y outer wall [EB].

#declare un1_cooling_storey_lo_Z = +18.700; // Z of floor rOP.
#declare un1_cooling_storey_hi_Z = +25.700; // Z of ceiling rOP [TBC].

// DEMINERALIZER STOREY

#declare un1_demineralizer_storey_west_wall_thk = 1.000; // Typical thickness of -X outer wall [EB].
#declare un1_demineralizer_storey_east_wall_thk = 0.600; // Typical thickness of +X outer wall [EB].

#declare un1_demineralizer_storey_south_wall_thk = 0.900; // Typical thickness of -Y outer wall [EB].
#declare un1_demineralizer_storey_north_wall_thk = 1.200; // Typical thickness of +Y outer wall [EB].

#declare un1_demineralizer_storey_lo_Z = +25.900; // Z of floor rOP.
#declare un1_demineralizer_storey_hi_Z = +30.500; // Z of ceiling rOP [TBC].

// CONDENSER STOREY

#declare un1_condenser_storey_west_wall_thk = 1.000; // Typical thickness of -X outer wall [EB].
#declare un1_condenser_storey_east_wall_thk = 0.600; // Typical thickness of +X outer wall [EB].

#declare un1_condenser_storey_south_wall_thk = 0.900; // Typical thickness of -Y outer wall [EB].
#declare un1_condenser_storey_north_wall_thk = 0.900; // Typical thickness of +Y outer wall [EB].

#declare un1_condenser_storey_lo_Z = +31.300; // Z of floor rOP.
#declare un1_condenser_storey_hi_Z = +38.700; // Z of ceiling rOP [TBC].

// SERVICE STOREY

#declare un1_service_storey_west_wall_thk = 0.200; // Thickness of -X outer concrete shell [EB].
#declare un1_service_storey_east_wall_thk = 0.200; // Thickness of +X outer concrete shell [EB].

#declare un1_service_storey_south_wall_thk = 0.200; // Thickness of -Y outer concrete shell [EB].
#declare un1_service_storey_north_wall_thk = 0.200; // Thickness of +Y outer concrete shell [EB].

#declare un1_service_storey_lo_Z = un1_service_floor_Z; // Z of service floor rOP.

#declare un1_service_storey_hi_Z = +54.400;    // Z of service space ceiling at center rOP [TBC].

// ROOF "STOREY"

#declare un1_roof_storey_west_wall_thk = 0.200; // Thickness of -X outer concrete shell [EB].
#declare un1_roof_storey_east_wall_thk = 0.200; // Thickness of +X outer concrete shell [EB].

#declare un1_roof_storey_south_wall_thk = 0.200; // Thickness of -Y outer concrete shell [EB].
#declare un1_roof_storey_north_wall_thk = 0.200; // Thickness of +Y outer concrete shell [EB].

#declare un1_roof_storey_lo_Z = +54.600; // Z of floor at center rOP.

#declare un1_roof_tilt = 0.547;          // Tilt of roof in the X direction (degrees) [EB]
